@@ -1,7 +1,7 @@
 import pandas as pd
 import adinference
 from adinference import admlp
-# from adlinear import utilities as utl
+from adlinear import utilities as utl
 from adlinear import nmf_k_estimator as ke
 import root_path
 from transparentpath import Path
@@ -38,26 +38,35 @@ if __name__ == "__main__":
     df_train = df_train.drop([col for col in df_train.columns if col.find("entropy") >= 0],
                              axis='columns', inplace=False)
     train_file_path = Path(data_path / "screeplots.csv", fs="local")
-    train_file_path.write(df_train)
+    train_file_already_saved = True
+    if not train_file_already_saved:
+        train_file_path.write(df_train)
 
     mymlp = adinference.admlp.AdMlp(models_path, optk_model_dir)
     mymlp.load_model()
 
-    my_k_estimator = ke.NCompEstimator
+    my_k_estimator = ke.NCompEstimator(inference_model=mymlp)
 
-    nb_clusters = 10
-    h_size = 50
-    h_avg = int(h_size / nb_clusters)
-    w_size = 400
-    w_avg = int(w_size / nb_clusters)
-    icorrmin = 0.80
-    icorrmax = 0.99
-    xcorrmin = 0.01
-    xcorrmax = 0.30
+    est_do_random_matrix = False
+    if est_do_random_matrix:
+        nb_clusters = 10
+        h_size = 50
+        h_avg = int(h_size / nb_clusters)
+        w_size = 1000
+        w_avg = int(w_size / nb_clusters)
+        icorrmin = 0.80
+        icorrmax = 0.99
+        xcorrmin = 0.01
+        xcorrmax = 0.30
 
-    mat, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
-                                                   avg_w_clust=w_avg, avg_h_clust=h_avg,
-                                                   h_icorr_min=icorrmin, h_xcorr_max=xcorrmax,
-                                                   w_icorr_min=icorrmin, w_xcorr_max=xcorrmax)
-    preds = my_k_estimator.estimate_ncomp(mat=mat, inference_model=mymlp)
+        mat, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
+                                                       avg_w_clust=w_avg, avg_h_clust=h_avg,
+                                                       h_icorr_min=icorrmin, h_xcorr_max=xcorrmax,
+                                                       w_icorr_min=icorrmin, w_xcorr_max=xcorrmax)
+        preds = my_k_estimator.estimate_ncomp(mat=mat)
+    est_do_train_data = True
+    if est_do_train_data:
+        train_data = df_train.drop(['Position'], axis="columns", inplace=False)
+        train_data, _, _ = utl.normalize_by_columns(train_data, make_positive=False)
+        train_preds = my_k_estimator.get_predictions(train_data)
     pass
